@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogAny::NullLogging;
 
-our $DATE = '2016-11-23'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,7 +36,7 @@ Bencher::Scenario::LogAny::NullLogging - Benchmark Log::Any logging speed with N
 
 =head1 VERSION
 
-This document describes version 0.07 of Bencher::Scenario::LogAny::NullLogging (from Perl distribution Bencher-Scenarios-LogAny), released on 2016-11-23.
+This document describes version 0.08 of Bencher::Scenario::LogAny::NullLogging (from Perl distribution Bencher-Scenarios-LogAny), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with C<< bencher -m LogAny::NullLogging --env-hashes-json '[{"PERL5OPT":"-Iarchive/Log-Any-1.040/lib"},{"PERL5OPT":"-Iarchive/Log-Any-1.041/lib"}]' >>:
 
@@ -82,12 +82,15 @@ Benchmark with C<< bencher -m LogAny::NullLogging --env-hashes-json '[{"PERL5OPT
  +----------------+--------------------------------------+-----------+-----------+------------+---------+---------+
  | participant    | env                                  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------+--------------------------------------+-----------+-----------+------------+---------+---------+
- | 100k_log_trace | PERL5OPT=-Iarchive/Log-Any-1.041/lib |      21   |      47.6 |       1    | 3.4e-05 |      20 |
- | 100k_log_trace | PERL5OPT=-Iarchive/Log-Any-1.040/lib |      21.6 |      46.4 |       1.03 | 2.4e-05 |      21 |
- | 100k_is_trace  | PERL5OPT=-Iarchive/Log-Any-1.041/lib |      32   |      31   |       1.5  | 3.9e-05 |      20 |
- | 100k_is_trace  | PERL5OPT=-Iarchive/Log-Any-1.040/lib |      33   |      31   |       1.6  | 4.4e-05 |      20 |
+ | 100k_log_trace | PERL5OPT=-Iarchive/Log-Any-1.041/lib |        15 |        67 |        1   | 0.00019 |      20 |
+ | 100k_log_trace | PERL5OPT=-Iarchive/Log-Any-1.040/lib |        15 |        66 |        1   | 0.00029 |      21 |
+ | 100k_is_trace  | PERL5OPT=-Iarchive/Log-Any-1.041/lib |        22 |        45 |        1.5 | 0.00015 |      20 |
+ | 100k_is_trace  | PERL5OPT=-Iarchive/Log-Any-1.040/lib |        23 |        44 |        1.5 | 0.00021 |      21 |
  +----------------+--------------------------------------+-----------+-----------+------------+---------+---------+
 
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-LogAny>.
@@ -110,7 +113,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
